pub struct ProfileFileRegionProvider { /* private fields */ }Expand description
Load a region from a profile file
This provider will attempt to load AWS shared configuration, then read the region property
from the active profile.
Location of Profile Files
- The location of the config file will be loaded from the
AWS_CONFIG_FILEenvironment variable with a fallback to~/.aws/config - The location of the credentials file will be loaded from the
AWS_SHARED_CREDENTIALS_FILEenvironment variable with a fallback to~/.aws/credentials
The location of these files can also be customized programmatically using ProfileFiles.
Home directory resolution
Home directory resolution is implemented to match the behavior of the CLI & Python. ~ is only
used for home directory resolution when it:
- Starts the path
- Is followed immediately by
/or a platform specific separator. (On windows,~/and~\both resolve to the home directory.
When determining the home directory, the following environment variables are checked:
HOMEon all platformsUSERPROFILEon Windows- The concatenation of
HOMEDRIVEandHOMEPATHon Windows ($HOMEDRIVE$HOMEPATH)
Examples
Loads “us-west-2” as the region
[default]
region = us-west-2Loads us-east-1 as the region if and only if the AWS_PROFILE environment variable is set
to other.
[profile other]
region = us-east-1This provider is part of the default region provider chain.
Implementations
Sourceimpl ProfileFileRegionProvider
impl ProfileFileRegionProvider
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new ProfileFileRegionProvider
To override the selected profile, set the AWS_PROFILE environment variable or use the Builder.
Sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Builder to construct a ProfileFileRegionProvider